<!-- 
Author(s): Shibaji Chakraborty, Xueling Shi

Disclaimer:
SCUBAS is under the MIT license found in the root directory LICENSE.md 
Everyone is permitted to copy and distribute verbatim copies of this license 
document.

This version of the MIT Public License incorporates the terms
and conditions of MIT General Public License.
-->
# INTERMAGNET International Real-time Magnetic Observatory Network
INTERMAGNET - the global network of observatories, monitoring the Earth's magnetic field. At this site you can find data and information from geomagnetic observatories around the world. The INTERMAGNET programme exists to establish a global network of cooperating digital magnetic observatories, adopting modern standard specifications for measuring and recording equipment, in order to facilitate data exchanges and the production of geomagnetic products in close to real time.

## Accessing the data by HAPI interface
The host for the INTERMAGNET data portal is moving from Natural Resources Canada (NRCan) to the British Geological Survey (BGS). A number of services provided by NRCan, including web site download and ftp access to INTERMAGNET provisional and real-time data, will terminate on May 1st 2023. Replacement services are available at BGS. The service at BGS includes all INTERMAGNET data currently available from NRCan - the data has been copied between the two GINs.

> A HAPI web service interface to INTERMAGNET data by this [link](https://imag-data.bgs.ac.uk/GIN_V1/hapi). Please find more information about [HAPI](https://hapi-server.github.io).
